@@ -405,6 +405,8 @@ void displaynextpiece(struct bl *bl)
       v.ycenter = (ymin+ymax)/2 ;
       v.xprod   = (xmax-xmin)-4 ;
       v.yprod   = (ymax-ymin)-4 ;
+      v.cross_eyed = 0 ;
+      v.eye_distance = 0 ;
 
       createtransfo(UNIT,&id,0.,-2.5,-2.5,5.) ;
 
